@@ -13,7 +13,7 @@ def get_instances_in_asg_by_lifecycle_state(credentials, asg_physical_id, lifecy
     return instances
 
 def resume_processes(credentials, asg_physical_id):
-    credentials.autoscale.suspend_processes(asg_physical_id, "ScheduledActions")
+    credentials.autoscale.suspend_processes(asg_physical_id, ["ScheduledActions"])
 
 def suspend_processes(credentials, asg_physical_id):
-    credentials.autoscale.suspend_processes(asg_physical_id, "ScheduledActions")
\ No newline at end of file
+    credentials.autoscale.suspend_processes(asg_physical_id, ["ScheduledActions"])
\ No newline at end of file
